@@ -37,7 +37,7 @@ def Create_New_Table(TABLE=None, NAME=None, NFIELDS=None, FIELDS_NAME0=None, FIE
     (-) binary\n
     Arguments
     ----------
-    - TABLE [`output data object`] : Table
+    - TABLE [`output table`] : Table
     - NAME [`text`] : Name. Default: New Table
     - NFIELDS [`integer number`] : Number of Attributes. Minimum: 1 Default: 2
     - FIELDS_NAME0 [`text`] : Field 1. Default: Field 1 Name
@@ -85,7 +85,7 @@ def run_tool_table_tools_0(TABLE=None, NAME=None, NFIELDS=None, FIELDS_NAME0=Non
     (-) binary\n
     Arguments
     ----------
-    - TABLE [`output data object`] : Table
+    - TABLE [`output table`] : Table
     - NAME [`text`] : Name. Default: New Table
     - NFIELDS [`integer number`] : Number of Attributes. Minimum: 1 Default: 2
     - FIELDS_NAME0 [`text`] : Field 1. Default: Field 1 Name
